# Contributing to the SpectrumX SDK

Please refer to our
[CONTRIBUTING](https://github.com/lucaspar/sds-code/blob/master/contributing.md) guide
for general contribution guidelines.

Other ways to contribute:

+ [Issue tracker](https://github.com/spectrumx/sds-code/issues/new/choose)
    + Reporting Bugs
    + Suggesting Enhancements
    + Asking Questions
+ Reporting Security Vulnerabilities
    + `crc-sds-list [·at·] nd.edu`
+ User support and content deletion requests
    + `crc-sds-list [·at·] nd.edu`
